Getting Started
===============

This :doc:`getting-started` guide is intended to assist the user with installing the library.

Install the package
-------------------

The latest version of :obj:`salp` can be installed from `PyPI <https://pypi.org/project/salp/>`_ using `pip`.

.. code-block:: console

   $ python3 -m pip install salp

Import the :obj:`salp` package in Python.

.. ipython:: python

   import salp
   salp.__version__


See :doc:`Basic Usage </basic-usage/basic-usage>` for some examples.
